#========================================================================================
# package      DE_EPAGES::GoogleBase::t::GoogleBaseExportDriver_Priceformat
# state        public
#----------------------------------------------------------------------------------------
# description  Test if the price is in the right format
#========================================================================================
package DE_EPAGES::GoogleBase::t::GoogleBaseExportDriver_Priceformat;

use strict;
use DE_EPAGES::Core::API::Error qw ( ExistsError GetError );
use DE_EPAGES::Core::API::File qw ( GetFileContent );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore );
use DE_EPAGES::GoogleBase::API::CSV::GoogleBaseProductsExportDriver;
use DE_EPAGES::Object::API::Factory qw (
    ExistsObjectByPath
    JoinObjectPath
    LoadObjectByPath
    LoadRootObject
);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw ( ImportObjects );
use File::Temp qw ( tempdir tempfile );
use Readonly;
use Test::More;
use Time::HiRes;

Readonly my $ROOTPATH => '/TestShop';

sub Main {
    RunOnStore(
        'Store' => GetTestSite(),
        'Sub'   => sub {
            ok( Init(), 'initialization' );
            # tests
            eval {
                my $CSV = GetCVS_AsString();
                # the test price values comes from import.xml
                TestIfFormatedPriceIsInCSV($CSV, '339.95 EUR');
                TestIfFormatedPriceIsInCSV($CSV, '119.00 EUR');
                TestIfFormatedPriceIsInCSV($CSV, ':::12.00 EUR');
                 };
             if ( ExistsError() ) {
                my $Error = GetError();
                fail( 'Error: ' . $Error->longMessage );
            }
            ok( Cleanup(), 'cleanup' );
            done_testing();
        }
    );
}
sub TestIfFormatedPriceIsInCSV{
    my ($CSV, $FormatedPrice) = @_;
    my $TestName = (caller(0))[3];
    like($CSV, qr/$FormatedPrice/ms, "$TestName - The formated price is in the CSV - '$FormatedPrice'");
}

sub GetCVS_AsString {
    my $StartTime;
    my $FinishingTime;
    my $PortalConfig = LoadObjectByPath($ROOTPATH)->path( JoinObjectPath( [ 'TestShop', 'PortalConfigs', 'GoogleBase_de_DE' ] ) );
    isa_ok( $PortalConfig, 'DE_EPAGES::ProductPortal::API::Object::PortalConfigWithUpload' );
    my $dir = tempdir( CLEANUP => 1 );
    my (undef, $FileName) = tempfile( DIR => $dir );
    $StartTime = time;
    $PortalConfig->exportPortal($FileName, 1);
    $FinishingTime = time;
    note (sprintf('The Export needed %.4f seconds ', $FinishingTime - $StartTime));
    ok (-f $FileName,'export file created');
    return ${ GetFileContent($FileName) };
}

sub Cleanup {
    return 1 if $ENV{'SKIP_CLEANUP'};
    LoadObjectByPath($ROOTPATH)->delete if ExistsObjectByPath($ROOTPATH);
    return 1;
}

sub Init {
    return 1 if ExistsObjectByPath($ROOTPATH) && $ENV{'SKIP_CLEANUP'};
    Cleanup();
    LoadRootObject()->insertChild( 'Object', { Alias => 'TestShop' } );
    ImportObjects( 'import.xml', $ROOTPATH );
    return 1;
}

RunScript( Debug => 1, Sub => \&Main );

1;