use strict;

use DE_EPAGES::Core::API::Script qw ( RunScript );
use Test::More;
use DE_EPAGES::GoogleBase::API::CSV::GoogleBaseProductsExportDriver;
use DE_EPAGES::GoogleBase::t::MockingExporterObject;
use DE_EPAGES::GoogleBase::t::MockProduct;
use DE_EPAGES::GoogleBase::API::Constants qw ($SUPPORTED_LOCAL_IDS);

my $NameSpace = \%DE_EPAGES::GoogleBase::API::CSV::GoogleBaseProductsExportDriver::;
sub Main {
    testMethodWithAllLocals('item_group_id');
    testMethodWithAllLocals('size');
    testMethodWithAllLocals('color');
    testMethodWithAllLocals('age_group');
    testMethodWithAllLocals('gender');
    testMethodWithAllLocals('material');
    testMethodWithAllLocals('pattern');
    done_testing();
}

sub testMethodWithAllLocals {
    my ($MethodName) = @_;
    note ('--------------------------------------------------');
    note("test sub $MethodName()");
    note ('--------------------------------------------------');
    my $False = '';
    my $Answer = 'TestResponse';
    my $Product = DE_EPAGES::GoogleBase::t::MockProduct->new();
    my $TestExporterObject = DE_EPAGES::GoogleBase::t::MockingExporterObject->new();
    $Product->setValue('Class',$Product);
    $Product->setValue('Alias',$Answer);
    $Product->setValue( 'getWithParent', $Product);
    foreach my $SupportedLocalID (@{$SUPPORTED_LOCAL_IDS}){
        $TestExporterObject->SetLocale($SupportedLocalID );
        is ($NameSpace->{$MethodName}($TestExporterObject,$Product),$Answer,"correct answer with $SupportedLocalID");
    }
    $Product->setValue( 'getWithParent', []);
    foreach my $SupportedLocalID (@{$SUPPORTED_LOCAL_IDS}){
        $TestExporterObject->SetLocale($SupportedLocalID );
        is ($NameSpace->{$MethodName}($TestExporterObject,$Product),$False,"correct answer with $SupportedLocalID when Product is undef");
    }
    $Product->setValue( 'getWithParent', 'IAmNotBlessedAndNotAnArray');
    foreach my $SupportedLocalID (@{$SUPPORTED_LOCAL_IDS}){
        $TestExporterObject->SetLocale($SupportedLocalID );
        is ($NameSpace->{$MethodName}($TestExporterObject,$Product)
            ,'IAmNotBlessedAndNotAnArray'
            ,"correct answer with $SupportedLocalID and Product not a blessed array");
    }
    $TestExporterObject->SetLocale('xx_XX');
    is ($NameSpace->{$MethodName}($TestExporterObject,$Product),$False,'correct behavior with wrong local xx_XX');
}

RunScript( Sub => \&Main );