jQuery.plugin('de_epages.presentation.ui.stateselection', {
	plugin:	['jQuery.tmpl', 'jQuery.ui.widget', 'de_epages.core', 'ep.ui.validate', 'ep.ui.input'],
	tmpl: ['de_epages.presentation.ui.stateselection']
}, function ($) {

	// The widget.
	$.widget('de_epages.presentation.ui.Stateselection', {

		options : {},

		_create : function () {
			var self = this,
					o = self.options;

			// Merge in options from data attribute.
			$.extend(true, o, $.parseJSON(self.element.attr('data-de_epages-presentation-ui-stateselection')));

			// Init *change* listener on corresponding *country* *select* element.
			self.countrySelect = $('#' + o.countrySelectId).on('change.presentationUiStateselection', self.Proxy('_onCountrySelect'));

			// Init input containers.
			o.cssClasses.inputLabelling && (self.inputLabelling = self.element.find('.' + o.cssClasses.inputLabelling));
			self.inputField = (o.cssClasses.inputField && self.element.find('.' + o.cssClasses.inputField)) || self.element;

			// Trigger initial rendering by setting *countryId*.
			var initalCountryID = o.countryId ? o.countryId : self.countrySelect.val();
			self._setOption('countryId', initalCountryID, true);
		},

		_setOption : function (key, value, calledByCreate) {
			if (key === 'countryId') {
				var self = this,
						o = self.options;

				// In case we already luckily guessed the countryId before, we do nothing.
				if (!calledByCreate && o.countryId === value) {
					return;
				}
				this.Inherited(arguments);

				// If there is no country selected we assume the country to be equal to the shop's country.
				if (!(o.countryId && self.countrySelect.length && o.shopRegistrationField.countryId.isVisibleName)) {
					o.countryId = o.shopAddressCountryId;
				}

				// Render input with newly selected *countryId*.
				if (o.countryId !== '' ) {
					self._render();
				}
			}
		},

		_onCountrySelect : function (event) {
			this._setOption('countryId', this.countrySelect.children(':selected').val());
		},

		_render : function () {
			var self = this,
					o = self.options;

			// Clean the plate.
			if (self.input) {self.input.remove();}
			if (self.inputLabelling) {self.inputLabelling.empty();}

			var countryData = o.data[o.countryId],
					stateIsMandatory = o.shopRegistrationField.state.isMandatoryName || countryData.subdivsMandatory;

			if (stateIsMandatory || o.shopRegistrationField.state.isVisibleName) {
				// Render *input* template.
				self.input = ep($.tmpl('de_epages.presentation.ui.stateselection', {country : countryData}, o)).uiValidate({valid:!o.formError, required : stateIsMandatory});

				// Reset *preselectedState* option. Only used for initial *_create*.
				// E.g. the user is redirected to the form and already entered a state before.
				self._setOption('preselectedState', '');

				// Set *inputLabelling*.
				if (self.inputLabelling) {
					self.inputLabelling.append(o.input.label + (stateIsMandatory ? (' ' + o.input.mandatoryStar) : ''));
				}

				// Add *input* to *inputField*.
				self.input.appendTo(self.inputField);

				// Show *element*.
				self.element.removeClass('HideElement');
			}
			else {
				// Hide *element*.
				self.element.addClass('HideElement');
				// Add hidden input to overwrite previously value on the server-side.
				// This could/should be handled by the server, but currently is not.
				self.input = $('<input type="hidden"/>').attr({
					name : o.input.name,
					id : o.input.id,
					value : ''
				});
				self.input.appendTo(self.inputField);
			}
		},

		destroy : function () {
			this.countrySelect && this.countrySelect.length && this.countrySelect.off('change.presentationUiStateselection');
			this.inputLabelling && this.inputLabelling.empty();
			this.input && this.input.remove();
			this.Inherited(arguments);
		}

	});

});